#! /bin/sh
#
# Product setup script - Loki Entertainment Software

# Go to the proper setup directory (if not already there)
cd `dirname $0`

# Return the appropriate architecture string
DetectARCH()
{
	status=1
	case `uname -m` in
		i?86)  echo "x86"
			status=0;;
		x86_64)  echo "x86"
			status=0;;
		*)     echo "`uname -m`"
			status=0;;
	esac
	return $status
}

# Return all the supported versions
DetectLIBC()
{
      status=1
	  if [ `uname -s` != Linux ]; then
		  echo "glibc-2.2"
		  return $status
	  fi
      if [ -d "/lib32" ]; then
          libdir="/lib32"
      elif [ -d "/emul/ia32-linux/lib" ]; then
          libdir="/emul/ia32-linux/lib"
      else
          libdir="/lib"
      fi
      for lc in "$libdir"/libc.so.6 "$libdir"/libc.so.6.? "$libdir"/libc.so.6.*
      do
          if [ -f "$lc" ]; then
              break
          fi
      done
      
      if [ -f "$lc" ]; then
          libc=`strings "$libdir"/libc.so.6* | sed -e '/^GLIBC_[0-9].[0-9]$/ !d' -e 's/GLIBC_/glibc-/' | sort -r`
          if [ -z "$libc" ]; then
              echo "unknown"
          else
              echo "$libc"
              status=0
          fi
      elif [ -f "$libdir"/libc.so.5 ]; then
	      echo "libc5"
	      status=0
      else
	      echo "unknown"
      fi
      return $status
}

# Detect the Linux environment
arch=`DetectARCH`
libc=`DetectLIBC`
os=`uname -s`

# Find the installation program
try_run()
{
    setup=$1
    shift
    fatal=$1
    if [ "$1" != "" ]; then
        shift
    fi

    # First find the binary we want to run
    failed=0
    setup_bin=""
    for ver in $libc
    do
        setup_bin="setup.data/bin/$os/$arch/$ver/$setup"
        if [ -f "$setup_bin" ]
        then
            break
        fi
    done
    if [ ! -f "$setup_bin" ]; then
        setup_bin="setup.data/bin/$os/$arch/$setup"
        if [ ! -f "$setup_bin" ]; then
            failed=1
        fi
    fi
    if [ "$failed" -eq 1 ]; then
        if [ "$fatal" != "" ]; then
            libc=`echo $libc | cut -d' ' -f1`
            cat <<__EOF__
This installation doesn't support $libc on $os / $arch

This product requires Linux running on a pentium-compatible (i386) system.

If you have additional questions, please visit http://support.codeweavers.com
__EOF__
            exit 1
        fi
        return $failed
    fi

    # Try to run the binary
    # The executable is here but we can't execute it from CD
    setup="$HOME/.setup$$"
    cp "$setup_bin" "$setup"
    chmod 700 "$setup"
    if [ "$fatal" != "" ]; then
        if [ -n "$CX_LOG" ]; then
            "$setup" $*
        else
            "$setup" $* 2>&1 | egrep -v "^Gdk-WARNING.*(Missing charsets in FontSet creation|JISX0201\\.1976-0|JISX0208\\.1983-0|KSC5601\\.1987-0|GB2312\\.1980-0)"
        fi
        failed=$?
    else
        "$setup" $* 2>/dev/null
        failed=$?
    fi
    rm -f "$setup"
    return $failed
}


# Try to run the setup program
status=0
rm -f "$setup"
try_run setup.gtk $* -fatal || {
    #echo "The setup program seems to have failed on $arch/$libc"
    #echo
    #echo "Please contact CrossOver Support at support@crossover.codeweavers.com"
    status=1
}
exit $status
